# coding: utf-8

"""
    CRM Objects

    CRM objects such as companies, contacts, deals, line items, products, tickets, and quotes are standard objects in HubSpot’s CRM. These core building blocks support custom properties, store critical information, and play a central role in the HubSpot application.  ## Supported Object Types  This API provides access to collections of CRM objects, which return a map of property names to values. Each object type has its own set of default properties, which can be found by exploring the [CRM Object Properties API](https://developers.hubspot.com/docs/methods/crm-properties/crm-properties-overview).  |Object Type |Properties returned by default | |--|--| | `companies` | `name`, `domain` | | `contacts` | `firstname`, `lastname`, `email` | | `deals` | `dealname`, `amount`, `closedate`, `pipeline`, `dealstage` | | `products` | `name`, `description`, `price` | | `tickets` | `content`, `hs_pipeline`, `hs_pipeline_stage`, `hs_ticket_category`, `hs_ticket_priority`, `subject` |  Find a list of all properties for an object type using the [CRM Object Properties](https://developers.hubspot.com/docs/methods/crm-properties/get-properties) API. e.g. `GET https://api.hubapi.com/properties/v2/companies/properties`. Change the properties returned in the response using the `properties` array in the request body.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.objects.configuration import Configuration


class FilterGroup(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"filters": "list[Filter]"}

    attribute_map = {"filters": "filters"}

    def __init__(self, filters=None, local_vars_configuration=None):  # noqa: E501
        """FilterGroup - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._filters = None
        self.discriminator = None

        self.filters = filters

    @property
    def filters(self):
        """Gets the filters of this FilterGroup.  # noqa: E501


        :return: The filters of this FilterGroup.  # noqa: E501
        :rtype: list[Filter]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """Sets the filters of this FilterGroup.


        :param filters: The filters of this FilterGroup.  # noqa: E501
        :type filters: list[Filter]
        """
        if self.local_vars_configuration.client_side_validation and filters is None:  # noqa: E501
            raise ValueError("Invalid value for `filters`, must not be `None`")  # noqa: E501

        self._filters = filters

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FilterGroup):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FilterGroup):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Schemas

    The CRM uses schemas to define how custom objects should store and represent information in the HubSpot CRM. Schemas define details about an object's type, properties, and associations. The schema can be uniquely identified by its **object type ID**.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.schemas.configuration import Configuration


class ModelProperty(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "hidden": "bool",
        "display_order": "int",
        "description": "str",
        "show_currency_symbol": "bool",
        "type": "str",
        "hubspot_defined": "bool",
        "created_at": "datetime",
        "archived": "bool",
        "options": "list[Option]",
        "has_unique_value": "bool",
        "calculated": "bool",
        "external_options": "bool",
        "updated_at": "datetime",
        "created_user_id": "str",
        "modification_metadata": "PropertyModificationMetadata",
        "sensitive_data_categories": "list[str]",
        "label": "str",
        "form_field": "bool",
        "data_sensitivity": "str",
        "archived_at": "datetime",
        "group_name": "str",
        "referenced_object_type": "str",
        "name": "str",
        "calculation_formula": "str",
        "field_type": "str",
        "updated_user_id": "str",
    }

    attribute_map = {
        "hidden": "hidden",
        "display_order": "displayOrder",
        "description": "description",
        "show_currency_symbol": "showCurrencySymbol",
        "type": "type",
        "hubspot_defined": "hubspotDefined",
        "created_at": "createdAt",
        "archived": "archived",
        "options": "options",
        "has_unique_value": "hasUniqueValue",
        "calculated": "calculated",
        "external_options": "externalOptions",
        "updated_at": "updatedAt",
        "created_user_id": "createdUserId",
        "modification_metadata": "modificationMetadata",
        "sensitive_data_categories": "sensitiveDataCategories",
        "label": "label",
        "form_field": "formField",
        "data_sensitivity": "dataSensitivity",
        "archived_at": "archivedAt",
        "group_name": "groupName",
        "referenced_object_type": "referencedObjectType",
        "name": "name",
        "calculation_formula": "calculationFormula",
        "field_type": "fieldType",
        "updated_user_id": "updatedUserId",
    }

    def __init__(
        self,
        hidden=None,
        display_order=None,
        description=None,
        show_currency_symbol=None,
        type=None,
        hubspot_defined=None,
        created_at=None,
        archived=None,
        options=None,
        has_unique_value=None,
        calculated=None,
        external_options=None,
        updated_at=None,
        created_user_id=None,
        modification_metadata=None,
        sensitive_data_categories=None,
        label=None,
        form_field=None,
        data_sensitivity=None,
        archived_at=None,
        group_name=None,
        referenced_object_type=None,
        name=None,
        calculation_formula=None,
        field_type=None,
        updated_user_id=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """ModelProperty - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._hidden = None
        self._display_order = None
        self._description = None
        self._show_currency_symbol = None
        self._type = None
        self._hubspot_defined = None
        self._created_at = None
        self._archived = None
        self._options = None
        self._has_unique_value = None
        self._calculated = None
        self._external_options = None
        self._updated_at = None
        self._created_user_id = None
        self._modification_metadata = None
        self._sensitive_data_categories = None
        self._label = None
        self._form_field = None
        self._data_sensitivity = None
        self._archived_at = None
        self._group_name = None
        self._referenced_object_type = None
        self._name = None
        self._calculation_formula = None
        self._field_type = None
        self._updated_user_id = None
        self.discriminator = None

        if hidden is not None:
            self.hidden = hidden
        if display_order is not None:
            self.display_order = display_order
        self.description = description
        if show_currency_symbol is not None:
            self.show_currency_symbol = show_currency_symbol
        self.type = type
        if hubspot_defined is not None:
            self.hubspot_defined = hubspot_defined
        if created_at is not None:
            self.created_at = created_at
        if archived is not None:
            self.archived = archived
        self.options = options
        if has_unique_value is not None:
            self.has_unique_value = has_unique_value
        if calculated is not None:
            self.calculated = calculated
        if external_options is not None:
            self.external_options = external_options
        if updated_at is not None:
            self.updated_at = updated_at
        if created_user_id is not None:
            self.created_user_id = created_user_id
        if modification_metadata is not None:
            self.modification_metadata = modification_metadata
        if sensitive_data_categories is not None:
            self.sensitive_data_categories = sensitive_data_categories
        self.label = label
        if form_field is not None:
            self.form_field = form_field
        if data_sensitivity is not None:
            self.data_sensitivity = data_sensitivity
        if archived_at is not None:
            self.archived_at = archived_at
        self.group_name = group_name
        if referenced_object_type is not None:
            self.referenced_object_type = referenced_object_type
        self.name = name
        if calculation_formula is not None:
            self.calculation_formula = calculation_formula
        self.field_type = field_type
        if updated_user_id is not None:
            self.updated_user_id = updated_user_id

    @property
    def hidden(self):
        """Gets the hidden of this ModelProperty.  # noqa: E501


        :return: The hidden of this ModelProperty.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this ModelProperty.


        :param hidden: The hidden of this ModelProperty.  # noqa: E501
        :type hidden: bool
        """

        self._hidden = hidden

    @property
    def display_order(self):
        """Gets the display_order of this ModelProperty.  # noqa: E501

        The order that this property should be displayed in the HubSpot UI relative to other properties for this object type. Properties are displayed in order starting with the lowest positive integer value. A value of -1 will cause the property to be displayed **after** any positive values.  # noqa: E501

        :return: The display_order of this ModelProperty.  # noqa: E501
        :rtype: int
        """
        return self._display_order

    @display_order.setter
    def display_order(self, display_order):
        """Sets the display_order of this ModelProperty.

        The order that this property should be displayed in the HubSpot UI relative to other properties for this object type. Properties are displayed in order starting with the lowest positive integer value. A value of -1 will cause the property to be displayed **after** any positive values.  # noqa: E501

        :param display_order: The display_order of this ModelProperty.  # noqa: E501
        :type display_order: int
        """

        self._display_order = display_order

    @property
    def description(self):
        """Gets the description of this ModelProperty.  # noqa: E501

        A description of the property that will be shown as help text in HubSpot.  # noqa: E501

        :return: The description of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ModelProperty.

        A description of the property that will be shown as help text in HubSpot.  # noqa: E501

        :param description: The description of this ModelProperty.  # noqa: E501
        :type description: str
        """
        if self.local_vars_configuration.client_side_validation and description is None:  # noqa: E501
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def show_currency_symbol(self):
        """Gets the show_currency_symbol of this ModelProperty.  # noqa: E501

        Whether the property will display the currency symbol set in the account settings.  # noqa: E501

        :return: The show_currency_symbol of this ModelProperty.  # noqa: E501
        :rtype: bool
        """
        return self._show_currency_symbol

    @show_currency_symbol.setter
    def show_currency_symbol(self, show_currency_symbol):
        """Sets the show_currency_symbol of this ModelProperty.

        Whether the property will display the currency symbol set in the account settings.  # noqa: E501

        :param show_currency_symbol: The show_currency_symbol of this ModelProperty.  # noqa: E501
        :type show_currency_symbol: bool
        """

        self._show_currency_symbol = show_currency_symbol

    @property
    def type(self):
        """Gets the type of this ModelProperty.  # noqa: E501

        The property data type.  # noqa: E501

        :return: The type of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ModelProperty.

        The property data type.  # noqa: E501

        :param type: The type of this ModelProperty.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def hubspot_defined(self):
        """Gets the hubspot_defined of this ModelProperty.  # noqa: E501

        This will be true for default object properties built into HubSpot.  # noqa: E501

        :return: The hubspot_defined of this ModelProperty.  # noqa: E501
        :rtype: bool
        """
        return self._hubspot_defined

    @hubspot_defined.setter
    def hubspot_defined(self, hubspot_defined):
        """Sets the hubspot_defined of this ModelProperty.

        This will be true for default object properties built into HubSpot.  # noqa: E501

        :param hubspot_defined: The hubspot_defined of this ModelProperty.  # noqa: E501
        :type hubspot_defined: bool
        """

        self._hubspot_defined = hubspot_defined

    @property
    def created_at(self):
        """Gets the created_at of this ModelProperty.  # noqa: E501

        When the property was created  # noqa: E501

        :return: The created_at of this ModelProperty.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ModelProperty.

        When the property was created  # noqa: E501

        :param created_at: The created_at of this ModelProperty.  # noqa: E501
        :type created_at: datetime
        """

        self._created_at = created_at

    @property
    def archived(self):
        """Gets the archived of this ModelProperty.  # noqa: E501

        Whether or not the property is archived.  # noqa: E501

        :return: The archived of this ModelProperty.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this ModelProperty.

        Whether or not the property is archived.  # noqa: E501

        :param archived: The archived of this ModelProperty.  # noqa: E501
        :type archived: bool
        """

        self._archived = archived

    @property
    def options(self):
        """Gets the options of this ModelProperty.  # noqa: E501

        A list of valid options for the property. This field is required for enumerated properties, but will be empty for other property types.  # noqa: E501

        :return: The options of this ModelProperty.  # noqa: E501
        :rtype: list[Option]
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this ModelProperty.

        A list of valid options for the property. This field is required for enumerated properties, but will be empty for other property types.  # noqa: E501

        :param options: The options of this ModelProperty.  # noqa: E501
        :type options: list[Option]
        """
        if self.local_vars_configuration.client_side_validation and options is None:  # noqa: E501
            raise ValueError("Invalid value for `options`, must not be `None`")  # noqa: E501

        self._options = options

    @property
    def has_unique_value(self):
        """Gets the has_unique_value of this ModelProperty.  # noqa: E501

        Whether or not the property's value must be unique. Once set, this can't be changed.  # noqa: E501

        :return: The has_unique_value of this ModelProperty.  # noqa: E501
        :rtype: bool
        """
        return self._has_unique_value

    @has_unique_value.setter
    def has_unique_value(self, has_unique_value):
        """Sets the has_unique_value of this ModelProperty.

        Whether or not the property's value must be unique. Once set, this can't be changed.  # noqa: E501

        :param has_unique_value: The has_unique_value of this ModelProperty.  # noqa: E501
        :type has_unique_value: bool
        """

        self._has_unique_value = has_unique_value

    @property
    def calculated(self):
        """Gets the calculated of this ModelProperty.  # noqa: E501

        For default properties, true indicates that the property is calculated by a HubSpot process. It has no effect for custom properties.  # noqa: E501

        :return: The calculated of this ModelProperty.  # noqa: E501
        :rtype: bool
        """
        return self._calculated

    @calculated.setter
    def calculated(self, calculated):
        """Sets the calculated of this ModelProperty.

        For default properties, true indicates that the property is calculated by a HubSpot process. It has no effect for custom properties.  # noqa: E501

        :param calculated: The calculated of this ModelProperty.  # noqa: E501
        :type calculated: bool
        """

        self._calculated = calculated

    @property
    def external_options(self):
        """Gets the external_options of this ModelProperty.  # noqa: E501

        For default properties, true indicates that the options are stored externally to the property settings.  # noqa: E501

        :return: The external_options of this ModelProperty.  # noqa: E501
        :rtype: bool
        """
        return self._external_options

    @external_options.setter
    def external_options(self, external_options):
        """Sets the external_options of this ModelProperty.

        For default properties, true indicates that the options are stored externally to the property settings.  # noqa: E501

        :param external_options: The external_options of this ModelProperty.  # noqa: E501
        :type external_options: bool
        """

        self._external_options = external_options

    @property
    def updated_at(self):
        """Gets the updated_at of this ModelProperty.  # noqa: E501

          # noqa: E501

        :return: The updated_at of this ModelProperty.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this ModelProperty.

          # noqa: E501

        :param updated_at: The updated_at of this ModelProperty.  # noqa: E501
        :type updated_at: datetime
        """

        self._updated_at = updated_at

    @property
    def created_user_id(self):
        """Gets the created_user_id of this ModelProperty.  # noqa: E501

        The internal ID of the user who created the property in HubSpot. This field may not exist if the property was created outside of HubSpot.  # noqa: E501

        :return: The created_user_id of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._created_user_id

    @created_user_id.setter
    def created_user_id(self, created_user_id):
        """Sets the created_user_id of this ModelProperty.

        The internal ID of the user who created the property in HubSpot. This field may not exist if the property was created outside of HubSpot.  # noqa: E501

        :param created_user_id: The created_user_id of this ModelProperty.  # noqa: E501
        :type created_user_id: str
        """

        self._created_user_id = created_user_id

    @property
    def modification_metadata(self):
        """Gets the modification_metadata of this ModelProperty.  # noqa: E501


        :return: The modification_metadata of this ModelProperty.  # noqa: E501
        :rtype: PropertyModificationMetadata
        """
        return self._modification_metadata

    @modification_metadata.setter
    def modification_metadata(self, modification_metadata):
        """Sets the modification_metadata of this ModelProperty.


        :param modification_metadata: The modification_metadata of this ModelProperty.  # noqa: E501
        :type modification_metadata: PropertyModificationMetadata
        """

        self._modification_metadata = modification_metadata

    @property
    def sensitive_data_categories(self):
        """Gets the sensitive_data_categories of this ModelProperty.  # noqa: E501


        :return: The sensitive_data_categories of this ModelProperty.  # noqa: E501
        :rtype: list[str]
        """
        return self._sensitive_data_categories

    @sensitive_data_categories.setter
    def sensitive_data_categories(self, sensitive_data_categories):
        """Sets the sensitive_data_categories of this ModelProperty.


        :param sensitive_data_categories: The sensitive_data_categories of this ModelProperty.  # noqa: E501
        :type sensitive_data_categories: list[str]
        """

        self._sensitive_data_categories = sensitive_data_categories

    @property
    def label(self):
        """Gets the label of this ModelProperty.  # noqa: E501

        A human-readable property label that will be shown in HubSpot.  # noqa: E501

        :return: The label of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this ModelProperty.

        A human-readable property label that will be shown in HubSpot.  # noqa: E501

        :param label: The label of this ModelProperty.  # noqa: E501
        :type label: str
        """
        if self.local_vars_configuration.client_side_validation and label is None:  # noqa: E501
            raise ValueError("Invalid value for `label`, must not be `None`")  # noqa: E501

        self._label = label

    @property
    def form_field(self):
        """Gets the form_field of this ModelProperty.  # noqa: E501

        Whether or not the property can be used in a HubSpot form.  # noqa: E501

        :return: The form_field of this ModelProperty.  # noqa: E501
        :rtype: bool
        """
        return self._form_field

    @form_field.setter
    def form_field(self, form_field):
        """Sets the form_field of this ModelProperty.

        Whether or not the property can be used in a HubSpot form.  # noqa: E501

        :param form_field: The form_field of this ModelProperty.  # noqa: E501
        :type form_field: bool
        """

        self._form_field = form_field

    @property
    def data_sensitivity(self):
        """Gets the data_sensitivity of this ModelProperty.  # noqa: E501


        :return: The data_sensitivity of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._data_sensitivity

    @data_sensitivity.setter
    def data_sensitivity(self, data_sensitivity):
        """Sets the data_sensitivity of this ModelProperty.


        :param data_sensitivity: The data_sensitivity of this ModelProperty.  # noqa: E501
        :type data_sensitivity: str
        """
        allowed_values = ["non_sensitive", "sensitive", "highly_sensitive"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and data_sensitivity not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `data_sensitivity` ({0}), must be one of {1}".format(data_sensitivity, allowed_values))  # noqa: E501

        self._data_sensitivity = data_sensitivity

    @property
    def archived_at(self):
        """Gets the archived_at of this ModelProperty.  # noqa: E501

        When the property was archived.  # noqa: E501

        :return: The archived_at of this ModelProperty.  # noqa: E501
        :rtype: datetime
        """
        return self._archived_at

    @archived_at.setter
    def archived_at(self, archived_at):
        """Sets the archived_at of this ModelProperty.

        When the property was archived.  # noqa: E501

        :param archived_at: The archived_at of this ModelProperty.  # noqa: E501
        :type archived_at: datetime
        """

        self._archived_at = archived_at

    @property
    def group_name(self):
        """Gets the group_name of this ModelProperty.  # noqa: E501

        The name of the property group the property belongs to.  # noqa: E501

        :return: The group_name of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._group_name

    @group_name.setter
    def group_name(self, group_name):
        """Sets the group_name of this ModelProperty.

        The name of the property group the property belongs to.  # noqa: E501

        :param group_name: The group_name of this ModelProperty.  # noqa: E501
        :type group_name: str
        """
        if self.local_vars_configuration.client_side_validation and group_name is None:  # noqa: E501
            raise ValueError("Invalid value for `group_name`, must not be `None`")  # noqa: E501

        self._group_name = group_name

    @property
    def referenced_object_type(self):
        """Gets the referenced_object_type of this ModelProperty.  # noqa: E501

        If this property is related to other object(s), they'll be listed here.  # noqa: E501

        :return: The referenced_object_type of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._referenced_object_type

    @referenced_object_type.setter
    def referenced_object_type(self, referenced_object_type):
        """Sets the referenced_object_type of this ModelProperty.

        If this property is related to other object(s), they'll be listed here.  # noqa: E501

        :param referenced_object_type: The referenced_object_type of this ModelProperty.  # noqa: E501
        :type referenced_object_type: str
        """

        self._referenced_object_type = referenced_object_type

    @property
    def name(self):
        """Gets the name of this ModelProperty.  # noqa: E501

        The internal property name, which must be used when referencing the property via the API.  # noqa: E501

        :return: The name of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ModelProperty.

        The internal property name, which must be used when referencing the property via the API.  # noqa: E501

        :param name: The name of this ModelProperty.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def calculation_formula(self):
        """Gets the calculation_formula of this ModelProperty.  # noqa: E501


        :return: The calculation_formula of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._calculation_formula

    @calculation_formula.setter
    def calculation_formula(self, calculation_formula):
        """Sets the calculation_formula of this ModelProperty.


        :param calculation_formula: The calculation_formula of this ModelProperty.  # noqa: E501
        :type calculation_formula: str
        """

        self._calculation_formula = calculation_formula

    @property
    def field_type(self):
        """Gets the field_type of this ModelProperty.  # noqa: E501

        Controls how the property appears in HubSpot.  # noqa: E501

        :return: The field_type of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._field_type

    @field_type.setter
    def field_type(self, field_type):
        """Sets the field_type of this ModelProperty.

        Controls how the property appears in HubSpot.  # noqa: E501

        :param field_type: The field_type of this ModelProperty.  # noqa: E501
        :type field_type: str
        """
        if self.local_vars_configuration.client_side_validation and field_type is None:  # noqa: E501
            raise ValueError("Invalid value for `field_type`, must not be `None`")  # noqa: E501

        self._field_type = field_type

    @property
    def updated_user_id(self):
        """Gets the updated_user_id of this ModelProperty.  # noqa: E501

        The internal user ID of the user who updated the property in HubSpot. This field may not exist if the property was updated outside of HubSpot.  # noqa: E501

        :return: The updated_user_id of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._updated_user_id

    @updated_user_id.setter
    def updated_user_id(self, updated_user_id):
        """Sets the updated_user_id of this ModelProperty.

        The internal user ID of the user who updated the property in HubSpot. This field may not exist if the property was updated outside of HubSpot.  # noqa: E501

        :param updated_user_id: The updated_user_id of this ModelProperty.  # noqa: E501
        :type updated_user_id: str
        """

        self._updated_user_id = updated_user_id

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelProperty):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelProperty):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Timeline

    This feature allows an app to create and configure custom events that can show up in the timelines of certain CRM objects like contacts, companies, tickets, or deals. You'll find multiple use cases for this API in the sections below.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.timeline.configuration import Configuration


class ErrorDetail(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"sub_category": "str", "code": "str", "_in": "str", "context": "dict[str, list[str]]", "message": "str"}

    attribute_map = {"sub_category": "subCategory", "code": "code", "_in": "in", "context": "context", "message": "message"}

    def __init__(self, sub_category=None, code=None, _in=None, context=None, message=None, local_vars_configuration=None):  # noqa: E501
        """ErrorDetail - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._sub_category = None
        self._code = None
        self.__in = None
        self._context = None
        self._message = None
        self.discriminator = None

        if sub_category is not None:
            self.sub_category = sub_category
        if code is not None:
            self.code = code
        if _in is not None:
            self._in = _in
        if context is not None:
            self.context = context
        self.message = message

    @property
    def sub_category(self):
        """Gets the sub_category of this ErrorDetail.  # noqa: E501

        A specific category that contains more specific detail about the error  # noqa: E501

        :return: The sub_category of this ErrorDetail.  # noqa: E501
        :rtype: str
        """
        return self._sub_category

    @sub_category.setter
    def sub_category(self, sub_category):
        """Sets the sub_category of this ErrorDetail.

        A specific category that contains more specific detail about the error  # noqa: E501

        :param sub_category: The sub_category of this ErrorDetail.  # noqa: E501
        :type sub_category: str
        """

        self._sub_category = sub_category

    @property
    def code(self):
        """Gets the code of this ErrorDetail.  # noqa: E501

        The status code associated with the error detail  # noqa: E501

        :return: The code of this ErrorDetail.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this ErrorDetail.

        The status code associated with the error detail  # noqa: E501

        :param code: The code of this ErrorDetail.  # noqa: E501
        :type code: str
        """

        self._code = code

    @property
    def _in(self):
        """Gets the _in of this ErrorDetail.  # noqa: E501

        The name of the field or parameter in which the error was found.  # noqa: E501

        :return: The _in of this ErrorDetail.  # noqa: E501
        :rtype: str
        """
        return self.__in

    @_in.setter
    def _in(self, _in):
        """Sets the _in of this ErrorDetail.

        The name of the field or parameter in which the error was found.  # noqa: E501

        :param _in: The _in of this ErrorDetail.  # noqa: E501
        :type _in: str
        """

        self.__in = _in

    @property
    def context(self):
        """Gets the context of this ErrorDetail.  # noqa: E501

        Context about the error condition  # noqa: E501

        :return: The context of this ErrorDetail.  # noqa: E501
        :rtype: dict[str, list[str]]
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this ErrorDetail.

        Context about the error condition  # noqa: E501

        :param context: The context of this ErrorDetail.  # noqa: E501
        :type context: dict[str, list[str]]
        """

        self._context = context

    @property
    def message(self):
        """Gets the message of this ErrorDetail.  # noqa: E501

        A human readable message describing the error along with remediation steps where appropriate  # noqa: E501

        :return: The message of this ErrorDetail.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ErrorDetail.

        A human readable message describing the error along with remediation steps where appropriate  # noqa: E501

        :param message: The message of this ErrorDetail.  # noqa: E501
        :type message: str
        """
        if self.local_vars_configuration.client_side_validation and message is None:  # noqa: E501
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ErrorDetail):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ErrorDetail):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Video Conferencing Extension

    These APIs allow you to specify URLs that can be used to interact with a video conferencing application, to allow HubSpot to add video conference links to meeting requests with contacts.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.extensions.videoconferencing.api.settings_api import SettingsApi

# import ApiClient
from hubspot.crm.extensions.videoconferencing.api_client import ApiClient
from hubspot.crm.extensions.videoconferencing.configuration import Configuration
from hubspot.crm.extensions.videoconferencing.exceptions import OpenApiException
from hubspot.crm.extensions.videoconferencing.exceptions import ApiTypeError
from hubspot.crm.extensions.videoconferencing.exceptions import ApiValueError
from hubspot.crm.extensions.videoconferencing.exceptions import ApiKeyError
from hubspot.crm.extensions.videoconferencing.exceptions import ApiAttributeError
from hubspot.crm.extensions.videoconferencing.exceptions import ApiException

# import models into sdk package
from hubspot.crm.extensions.videoconferencing.models.error import Error
from hubspot.crm.extensions.videoconferencing.models.error_detail import ErrorDetail
from hubspot.crm.extensions.videoconferencing.models.external_settings import ExternalSettings



# coding: utf-8

# flake8: noqa

"""
    Feedback Submissions

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.objects.feedback_submissions.api.basic_api import BasicApi
from hubspot.crm.objects.feedback_submissions.api.batch_api import BatchApi
from hubspot.crm.objects.feedback_submissions.api.search_api import SearchApi

# import ApiClient
from hubspot.crm.objects.feedback_submissions.api_client import ApiClient
from hubspot.crm.objects.feedback_submissions.configuration import Configuration
from hubspot.crm.objects.feedback_submissions.exceptions import OpenApiException
from hubspot.crm.objects.feedback_submissions.exceptions import ApiTypeError
from hubspot.crm.objects.feedback_submissions.exceptions import ApiValueError
from hubspot.crm.objects.feedback_submissions.exceptions import ApiKeyError
from hubspot.crm.objects.feedback_submissions.exceptions import ApiAttributeError
from hubspot.crm.objects.feedback_submissions.exceptions import ApiException

# import models into sdk package
from hubspot.crm.objects.feedback_submissions.models.associated_id import AssociatedId
from hubspot.crm.objects.feedback_submissions.models.batch_read_input_simple_public_object_id import BatchReadInputSimplePublicObjectId
from hubspot.crm.objects.feedback_submissions.models.batch_response_simple_public_object import BatchResponseSimplePublicObject
from hubspot.crm.objects.feedback_submissions.models.batch_response_simple_public_object_with_errors import BatchResponseSimplePublicObjectWithErrors
from hubspot.crm.objects.feedback_submissions.models.collection_response_associated_id import CollectionResponseAssociatedId
from hubspot.crm.objects.feedback_submissions.models.collection_response_simple_public_object_with_associations_forward_paging import CollectionResponseSimplePublicObjectWithAssociationsForwardPaging
from hubspot.crm.objects.feedback_submissions.models.collection_response_with_total_simple_public_object_forward_paging import CollectionResponseWithTotalSimplePublicObjectForwardPaging
from hubspot.crm.objects.feedback_submissions.models.error import Error
from hubspot.crm.objects.feedback_submissions.models.error_detail import ErrorDetail
from hubspot.crm.objects.feedback_submissions.models.filter import Filter
from hubspot.crm.objects.feedback_submissions.models.filter_group import FilterGroup
from hubspot.crm.objects.feedback_submissions.models.forward_paging import ForwardPaging
from hubspot.crm.objects.feedback_submissions.models.next_page import NextPage
from hubspot.crm.objects.feedback_submissions.models.paging import Paging
from hubspot.crm.objects.feedback_submissions.models.previous_page import PreviousPage
from hubspot.crm.objects.feedback_submissions.models.public_object_search_request import PublicObjectSearchRequest
from hubspot.crm.objects.feedback_submissions.models.simple_public_object import SimplePublicObject
from hubspot.crm.objects.feedback_submissions.models.simple_public_object_id import SimplePublicObjectId
from hubspot.crm.objects.feedback_submissions.models.simple_public_object_with_associations import SimplePublicObjectWithAssociations
from hubspot.crm.objects.feedback_submissions.models.standard_error import StandardError
from hubspot.crm.objects.feedback_submissions.models.value_with_timestamp import ValueWithTimestamp



import hubspot.cms.blogs.authors as api_client
from ....discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def author_api(self) -> api_client.BlogAuthorsApi:
        return self._configure_api_client(api_client, "BlogAuthorsApi")



# coding: utf-8

"""
    Marketing Emails

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.emails.configuration import Configuration


class PublicRssEmailDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "blog_image_max_width": "int",
        "blog_email_type": "str",
        "hubspot_blog_id": "str",
        "rss_entry_template": "str",
        "timing": "dict[str, object]",
        "max_entries": "int",
        "use_headline_as_subject": "bool",
        "blog_layout": "str",
        "url": "str",
    }

    attribute_map = {
        "blog_image_max_width": "blogImageMaxWidth",
        "blog_email_type": "blogEmailType",
        "hubspot_blog_id": "hubspotBlogId",
        "rss_entry_template": "rssEntryTemplate",
        "timing": "timing",
        "max_entries": "maxEntries",
        "use_headline_as_subject": "useHeadlineAsSubject",
        "blog_layout": "blogLayout",
        "url": "url",
    }

    def __init__(
        self,
        blog_image_max_width=None,
        blog_email_type=None,
        hubspot_blog_id=None,
        rss_entry_template=None,
        timing=None,
        max_entries=None,
        use_headline_as_subject=None,
        blog_layout=None,
        url=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicRssEmailDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._blog_image_max_width = None
        self._blog_email_type = None
        self._hubspot_blog_id = None
        self._rss_entry_template = None
        self._timing = None
        self._max_entries = None
        self._use_headline_as_subject = None
        self._blog_layout = None
        self._url = None
        self.discriminator = None

        if blog_image_max_width is not None:
            self.blog_image_max_width = blog_image_max_width
        if blog_email_type is not None:
            self.blog_email_type = blog_email_type
        if hubspot_blog_id is not None:
            self.hubspot_blog_id = hubspot_blog_id
        if rss_entry_template is not None:
            self.rss_entry_template = rss_entry_template
        if timing is not None:
            self.timing = timing
        if max_entries is not None:
            self.max_entries = max_entries
        if use_headline_as_subject is not None:
            self.use_headline_as_subject = use_headline_as_subject
        if blog_layout is not None:
            self.blog_layout = blog_layout
        if url is not None:
            self.url = url

    @property
    def blog_image_max_width(self):
        """Gets the blog_image_max_width of this PublicRssEmailDetails.  # noqa: E501

          # noqa: E501

        :return: The blog_image_max_width of this PublicRssEmailDetails.  # noqa: E501
        :rtype: int
        """
        return self._blog_image_max_width

    @blog_image_max_width.setter
    def blog_image_max_width(self, blog_image_max_width):
        """Sets the blog_image_max_width of this PublicRssEmailDetails.

          # noqa: E501

        :param blog_image_max_width: The blog_image_max_width of this PublicRssEmailDetails.  # noqa: E501
        :type blog_image_max_width: int
        """

        self._blog_image_max_width = blog_image_max_width

    @property
    def blog_email_type(self):
        """Gets the blog_email_type of this PublicRssEmailDetails.  # noqa: E501

          # noqa: E501

        :return: The blog_email_type of this PublicRssEmailDetails.  # noqa: E501
        :rtype: str
        """
        return self._blog_email_type

    @blog_email_type.setter
    def blog_email_type(self, blog_email_type):
        """Sets the blog_email_type of this PublicRssEmailDetails.

          # noqa: E501

        :param blog_email_type: The blog_email_type of this PublicRssEmailDetails.  # noqa: E501
        :type blog_email_type: str
        """

        self._blog_email_type = blog_email_type

    @property
    def hubspot_blog_id(self):
        """Gets the hubspot_blog_id of this PublicRssEmailDetails.  # noqa: E501

          # noqa: E501

        :return: The hubspot_blog_id of this PublicRssEmailDetails.  # noqa: E501
        :rtype: str
        """
        return self._hubspot_blog_id

    @hubspot_blog_id.setter
    def hubspot_blog_id(self, hubspot_blog_id):
        """Sets the hubspot_blog_id of this PublicRssEmailDetails.

          # noqa: E501

        :param hubspot_blog_id: The hubspot_blog_id of this PublicRssEmailDetails.  # noqa: E501
        :type hubspot_blog_id: str
        """

        self._hubspot_blog_id = hubspot_blog_id

    @property
    def rss_entry_template(self):
        """Gets the rss_entry_template of this PublicRssEmailDetails.  # noqa: E501

          # noqa: E501

        :return: The rss_entry_template of this PublicRssEmailDetails.  # noqa: E501
        :rtype: str
        """
        return self._rss_entry_template

    @rss_entry_template.setter
    def rss_entry_template(self, rss_entry_template):
        """Sets the rss_entry_template of this PublicRssEmailDetails.

          # noqa: E501

        :param rss_entry_template: The rss_entry_template of this PublicRssEmailDetails.  # noqa: E501
        :type rss_entry_template: str
        """

        self._rss_entry_template = rss_entry_template

    @property
    def timing(self):
        """Gets the timing of this PublicRssEmailDetails.  # noqa: E501

          # noqa: E501

        :return: The timing of this PublicRssEmailDetails.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._timing

    @timing.setter
    def timing(self, timing):
        """Sets the timing of this PublicRssEmailDetails.

          # noqa: E501

        :param timing: The timing of this PublicRssEmailDetails.  # noqa: E501
        :type timing: dict[str, object]
        """

        self._timing = timing

    @property
    def max_entries(self):
        """Gets the max_entries of this PublicRssEmailDetails.  # noqa: E501

          # noqa: E501

        :return: The max_entries of this PublicRssEmailDetails.  # noqa: E501
        :rtype: int
        """
        return self._max_entries

    @max_entries.setter
    def max_entries(self, max_entries):
        """Sets the max_entries of this PublicRssEmailDetails.

          # noqa: E501

        :param max_entries: The max_entries of this PublicRssEmailDetails.  # noqa: E501
        :type max_entries: int
        """

        self._max_entries = max_entries

    @property
    def use_headline_as_subject(self):
        """Gets the use_headline_as_subject of this PublicRssEmailDetails.  # noqa: E501

          # noqa: E501

        :return: The use_headline_as_subject of this PublicRssEmailDetails.  # noqa: E501
        :rtype: bool
        """
        return self._use_headline_as_subject

    @use_headline_as_subject.setter
    def use_headline_as_subject(self, use_headline_as_subject):
        """Sets the use_headline_as_subject of this PublicRssEmailDetails.

          # noqa: E501

        :param use_headline_as_subject: The use_headline_as_subject of this PublicRssEmailDetails.  # noqa: E501
        :type use_headline_as_subject: bool
        """

        self._use_headline_as_subject = use_headline_as_subject

    @property
    def blog_layout(self):
        """Gets the blog_layout of this PublicRssEmailDetails.  # noqa: E501

          # noqa: E501

        :return: The blog_layout of this PublicRssEmailDetails.  # noqa: E501
        :rtype: str
        """
        return self._blog_layout

    @blog_layout.setter
    def blog_layout(self, blog_layout):
        """Sets the blog_layout of this PublicRssEmailDetails.

          # noqa: E501

        :param blog_layout: The blog_layout of this PublicRssEmailDetails.  # noqa: E501
        :type blog_layout: str
        """

        self._blog_layout = blog_layout

    @property
    def url(self):
        """Gets the url of this PublicRssEmailDetails.  # noqa: E501

          # noqa: E501

        :return: The url of this PublicRssEmailDetails.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this PublicRssEmailDetails.

          # noqa: E501

        :param url: The url of this PublicRssEmailDetails.  # noqa: E501
        :type url: str
        """

        self._url = url

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicRssEmailDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicRssEmailDetails):
            return True

        return self.to_dict() != other.to_dict()



import hubspot.settings.users as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def roles_api(self) -> api_client.RolesApi:
        return self._configure_api_client(api_client, "RolesApi")

    @property
    def teams_api(self) -> api_client.TeamsApi:
        return self._configure_api_client(api_client, "TeamsApi")

    @property
    def users_api(self) -> api_client.UsersApi:
        return self._configure_api_client(api_client, "UsersApi")



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.cms.blogs.blog_posts.api.basic_api import BasicApi
from hubspot.cms.blogs.blog_posts.api.batch_api import BatchApi
from hubspot.cms.blogs.blog_posts.api.multi_language_api import MultiLanguageApi



import hubspot.crm.associations.v4.schema as api_client
from .....discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):

    @property
    def definitions_api(self) -> api_client.DefinitionsApi:
        return self._configure_api_client(api_client, "DefinitionsApi")

    @property
    def definition_configurations_api(self) -> api_client.DefinitionConfigurationsApi:
        return self._configure_api_client(api_client, "DefinitionConfigurationsApi")



import hubspot.crm.lists as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def folders_api(self) -> api_client.FoldersApi:
        return self._configure_api_client(api_client, "FoldersApi")

    @property
    def lists_api(self) -> api_client.ListsApi:
        return self._configure_api_client(api_client, "ListsApi")

    @property
    def mapping_api(self) -> api_client.MappingApi:
        return self._configure_api_client(api_client, "MappingApi")

    @property
    def memberships_api(self) -> api_client.MembershipsApi:
        return self._configure_api_client(api_client, "MembershipsApi")



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.crm.associations.v4.schema.api.definition_configurations_api import DefinitionConfigurationsApi
from hubspot.crm.associations.v4.schema.api.definitions_api import DefinitionsApi



# coding: utf-8

# flake8: noqa
"""
    Authors

    Use these endpoints for interacting with Blog Posts, Blog Authors, and Blog Tags  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.cms.blogs.authors.models.attach_to_lang_primary_request_v_next import AttachToLangPrimaryRequestVNext
from hubspot.cms.blogs.authors.models.batch_input_blog_author import BatchInputBlogAuthor
from hubspot.cms.blogs.authors.models.batch_input_json_node import BatchInputJsonNode
from hubspot.cms.blogs.authors.models.batch_input_string import BatchInputString
from hubspot.cms.blogs.authors.models.batch_response_blog_author import BatchResponseBlogAuthor
from hubspot.cms.blogs.authors.models.batch_response_blog_author_with_errors import BatchResponseBlogAuthorWithErrors
from hubspot.cms.blogs.authors.models.blog_author import BlogAuthor
from hubspot.cms.blogs.authors.models.blog_author_clone_request_v_next import BlogAuthorCloneRequestVNext
from hubspot.cms.blogs.authors.models.collection_response_with_total_blog_author_forward_paging import CollectionResponseWithTotalBlogAuthorForwardPaging
from hubspot.cms.blogs.authors.models.detach_from_lang_group_request_v_next import DetachFromLangGroupRequestVNext
from hubspot.cms.blogs.authors.models.error import Error
from hubspot.cms.blogs.authors.models.error_detail import ErrorDetail
from hubspot.cms.blogs.authors.models.forward_paging import ForwardPaging
from hubspot.cms.blogs.authors.models.next_page import NextPage
from hubspot.cms.blogs.authors.models.set_new_language_primary_request_v_next import SetNewLanguagePrimaryRequestVNext
from hubspot.cms.blogs.authors.models.standard_error import StandardError
from hubspot.cms.blogs.authors.models.update_languages_request_v_next import UpdateLanguagesRequestVNext



# coding: utf-8

"""
    CRM Objects

    CRM objects such as companies, contacts, deals, line items, products, tickets, and quotes are standard objects in HubSpot’s CRM. These core building blocks support custom properties, store critical information, and play a central role in the HubSpot application.  ## Supported Object Types  This API provides access to collections of CRM objects, which return a map of property names to values. Each object type has its own set of default properties, which can be found by exploring the [CRM Object Properties API](https://developers.hubspot.com/docs/methods/crm-properties/crm-properties-overview).  |Object Type |Properties returned by default | |--|--| | `companies` | `name`, `domain` | | `contacts` | `firstname`, `lastname`, `email` | | `deals` | `dealname`, `amount`, `closedate`, `pipeline`, `dealstage` | | `products` | `name`, `description`, `price` | | `tickets` | `content`, `hs_pipeline`, `hs_pipeline_stage`, `hs_ticket_category`, `hs_ticket_priority`, `subject` |  Find a list of all properties for an object type using the [CRM Object Properties](https://developers.hubspot.com/docs/methods/crm-properties/get-properties) API. e.g. `GET https://api.hubapi.com/properties/v2/companies/properties`. Change the properties returned in the response using the `properties` array in the request body.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.objects.configuration import Configuration


class SimplePublicUpsertObject(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "created_at": "datetime",
        "archived": "bool",
        "archived_at": "datetime",
        "new": "bool",
        "properties_with_history": "dict[str, list[ValueWithTimestamp]]",
        "id": "str",
        "object_write_trace_id": "str",
        "properties": "dict[str, str]",
        "updated_at": "datetime",
    }

    attribute_map = {
        "created_at": "createdAt",
        "archived": "archived",
        "archived_at": "archivedAt",
        "new": "new",
        "properties_with_history": "propertiesWithHistory",
        "id": "id",
        "object_write_trace_id": "objectWriteTraceId",
        "properties": "properties",
        "updated_at": "updatedAt",
    }

    def __init__(
        self,
        created_at=None,
        archived=None,
        archived_at=None,
        new=None,
        properties_with_history=None,
        id=None,
        object_write_trace_id=None,
        properties=None,
        updated_at=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """SimplePublicUpsertObject - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_at = None
        self._archived = None
        self._archived_at = None
        self._new = None
        self._properties_with_history = None
        self._id = None
        self._object_write_trace_id = None
        self._properties = None
        self._updated_at = None
        self.discriminator = None

        self.created_at = created_at
        if archived is not None:
            self.archived = archived
        if archived_at is not None:
            self.archived_at = archived_at
        self.new = new
        if properties_with_history is not None:
            self.properties_with_history = properties_with_history
        self.id = id
        if object_write_trace_id is not None:
            self.object_write_trace_id = object_write_trace_id
        self.properties = properties
        self.updated_at = updated_at

    @property
    def created_at(self):
        """Gets the created_at of this SimplePublicUpsertObject.  # noqa: E501


        :return: The created_at of this SimplePublicUpsertObject.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this SimplePublicUpsertObject.


        :param created_at: The created_at of this SimplePublicUpsertObject.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def archived(self):
        """Gets the archived of this SimplePublicUpsertObject.  # noqa: E501


        :return: The archived of this SimplePublicUpsertObject.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this SimplePublicUpsertObject.


        :param archived: The archived of this SimplePublicUpsertObject.  # noqa: E501
        :type archived: bool
        """

        self._archived = archived

    @property
    def archived_at(self):
        """Gets the archived_at of this SimplePublicUpsertObject.  # noqa: E501


        :return: The archived_at of this SimplePublicUpsertObject.  # noqa: E501
        :rtype: datetime
        """
        return self._archived_at

    @archived_at.setter
    def archived_at(self, archived_at):
        """Sets the archived_at of this SimplePublicUpsertObject.


        :param archived_at: The archived_at of this SimplePublicUpsertObject.  # noqa: E501
        :type archived_at: datetime
        """

        self._archived_at = archived_at

    @property
    def new(self):
        """Gets the new of this SimplePublicUpsertObject.  # noqa: E501


        :return: The new of this SimplePublicUpsertObject.  # noqa: E501
        :rtype: bool
        """
        return self._new

    @new.setter
    def new(self, new):
        """Sets the new of this SimplePublicUpsertObject.


        :param new: The new of this SimplePublicUpsertObject.  # noqa: E501
        :type new: bool
        """
        if self.local_vars_configuration.client_side_validation and new is None:  # noqa: E501
            raise ValueError("Invalid value for `new`, must not be `None`")  # noqa: E501

        self._new = new

    @property
    def properties_with_history(self):
        """Gets the properties_with_history of this SimplePublicUpsertObject.  # noqa: E501


        :return: The properties_with_history of this SimplePublicUpsertObject.  # noqa: E501
        :rtype: dict[str, list[ValueWithTimestamp]]
        """
        return self._properties_with_history

    @properties_with_history.setter
    def properties_with_history(self, properties_with_history):
        """Sets the properties_with_history of this SimplePublicUpsertObject.


        :param properties_with_history: The properties_with_history of this SimplePublicUpsertObject.  # noqa: E501
        :type properties_with_history: dict[str, list[ValueWithTimestamp]]
        """

        self._properties_with_history = properties_with_history

    @property
    def id(self):
        """Gets the id of this SimplePublicUpsertObject.  # noqa: E501


        :return: The id of this SimplePublicUpsertObject.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SimplePublicUpsertObject.


        :param id: The id of this SimplePublicUpsertObject.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def object_write_trace_id(self):
        """Gets the object_write_trace_id of this SimplePublicUpsertObject.  # noqa: E501


        :return: The object_write_trace_id of this SimplePublicUpsertObject.  # noqa: E501
        :rtype: str
        """
        return self._object_write_trace_id

    @object_write_trace_id.setter
    def object_write_trace_id(self, object_write_trace_id):
        """Sets the object_write_trace_id of this SimplePublicUpsertObject.


        :param object_write_trace_id: The object_write_trace_id of this SimplePublicUpsertObject.  # noqa: E501
        :type object_write_trace_id: str
        """

        self._object_write_trace_id = object_write_trace_id

    @property
    def properties(self):
        """Gets the properties of this SimplePublicUpsertObject.  # noqa: E501


        :return: The properties of this SimplePublicUpsertObject.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this SimplePublicUpsertObject.


        :param properties: The properties of this SimplePublicUpsertObject.  # noqa: E501
        :type properties: dict[str, str]
        """
        if self.local_vars_configuration.client_side_validation and properties is None:  # noqa: E501
            raise ValueError("Invalid value for `properties`, must not be `None`")  # noqa: E501

        self._properties = properties

    @property
    def updated_at(self):
        """Gets the updated_at of this SimplePublicUpsertObject.  # noqa: E501


        :return: The updated_at of this SimplePublicUpsertObject.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this SimplePublicUpsertObject.


        :param updated_at: The updated_at of this SimplePublicUpsertObject.  # noqa: E501
        :type updated_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SimplePublicUpsertObject):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SimplePublicUpsertObject):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Public App Crm Cards

    Allows an app to extend the CRM UI by surfacing custom cards in the sidebar of record pages. These cards are defined up-front as part of app configuration, then populated by external data fetch requests when the record page is accessed by a user.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.extensions.cards.configuration import Configuration


class IntegratorObjectResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"link_url": "str", "tokens": "list[ObjectToken]", "id": "str", "title": "str", "actions": "list[IntegratorObjectResultActionsInner]"}

    attribute_map = {"link_url": "linkUrl", "tokens": "tokens", "id": "id", "title": "title", "actions": "actions"}

    def __init__(self, link_url=None, tokens=None, id=None, title=None, actions=None, local_vars_configuration=None):  # noqa: E501
        """IntegratorObjectResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._link_url = None
        self._tokens = None
        self._id = None
        self._title = None
        self._actions = None
        self.discriminator = None

        if link_url is not None:
            self.link_url = link_url
        self.tokens = tokens
        self.id = id
        self.title = title
        self.actions = actions

    @property
    def link_url(self):
        """Gets the link_url of this IntegratorObjectResult.  # noqa: E501


        :return: The link_url of this IntegratorObjectResult.  # noqa: E501
        :rtype: str
        """
        return self._link_url

    @link_url.setter
    def link_url(self, link_url):
        """Sets the link_url of this IntegratorObjectResult.


        :param link_url: The link_url of this IntegratorObjectResult.  # noqa: E501
        :type link_url: str
        """

        self._link_url = link_url

    @property
    def tokens(self):
        """Gets the tokens of this IntegratorObjectResult.  # noqa: E501


        :return: The tokens of this IntegratorObjectResult.  # noqa: E501
        :rtype: list[ObjectToken]
        """
        return self._tokens

    @tokens.setter
    def tokens(self, tokens):
        """Sets the tokens of this IntegratorObjectResult.


        :param tokens: The tokens of this IntegratorObjectResult.  # noqa: E501
        :type tokens: list[ObjectToken]
        """
        if self.local_vars_configuration.client_side_validation and tokens is None:  # noqa: E501
            raise ValueError("Invalid value for `tokens`, must not be `None`")  # noqa: E501

        self._tokens = tokens

    @property
    def id(self):
        """Gets the id of this IntegratorObjectResult.  # noqa: E501


        :return: The id of this IntegratorObjectResult.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IntegratorObjectResult.


        :param id: The id of this IntegratorObjectResult.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def title(self):
        """Gets the title of this IntegratorObjectResult.  # noqa: E501


        :return: The title of this IntegratorObjectResult.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this IntegratorObjectResult.


        :param title: The title of this IntegratorObjectResult.  # noqa: E501
        :type title: str
        """
        if self.local_vars_configuration.client_side_validation and title is None:  # noqa: E501
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def actions(self):
        """Gets the actions of this IntegratorObjectResult.  # noqa: E501


        :return: The actions of this IntegratorObjectResult.  # noqa: E501
        :rtype: list[IntegratorObjectResultActionsInner]
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """Sets the actions of this IntegratorObjectResult.


        :param actions: The actions of this IntegratorObjectResult.  # noqa: E501
        :type actions: list[IntegratorObjectResultActionsInner]
        """
        if self.local_vars_configuration.client_side_validation and actions is None:  # noqa: E501
            raise ValueError("Invalid value for `actions`, must not be `None`")  # noqa: E501

        self._actions = actions

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IntegratorObjectResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IntegratorObjectResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicSurveyMonkeyValueFilterValueComparison(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "include_objects_with_no_value_set": "bool",
        "operation_type": "str",
        "value": "str",
        "operator": "str",
        "requires_time_zone_conversion": "bool",
        "timestamp": "int",
        "upper_bound": "int",
        "lower_bound": "int",
        "default_comparison_value": "str",
        "comparison_property_name": "str",
        "number_of_days": "int",
        "values": "list[str]",
        "month": "str",
        "year": "int",
        "day": "int",
        "use_fiscal_year": "bool",
        "fiscal_year_start": "str",
        "time_unit_count": "int",
        "time_unit": "str",
        "endpoint_behavior": "str",
        "property_parser": "str",
        "time_point": "PublicTimePointOperationTimePoint",
        "type": "str",
        "upper_bound_endpoint_behavior": "str",
        "upper_bound_time_point": "PublicTimePointOperationTimePoint",
        "lower_bound_endpoint_behavior": "str",
        "lower_bound_time_point": "PublicTimePointOperationTimePoint",
    }

    attribute_map = {
        "include_objects_with_no_value_set": "includeObjectsWithNoValueSet",
        "operation_type": "operationType",
        "value": "value",
        "operator": "operator",
        "requires_time_zone_conversion": "requiresTimeZoneConversion",
        "timestamp": "timestamp",
        "upper_bound": "upperBound",
        "lower_bound": "lowerBound",
        "default_comparison_value": "defaultComparisonValue",
        "comparison_property_name": "comparisonPropertyName",
        "number_of_days": "numberOfDays",
        "values": "values",
        "month": "month",
        "year": "year",
        "day": "day",
        "use_fiscal_year": "useFiscalYear",
        "fiscal_year_start": "fiscalYearStart",
        "time_unit_count": "timeUnitCount",
        "time_unit": "timeUnit",
        "endpoint_behavior": "endpointBehavior",
        "property_parser": "propertyParser",
        "time_point": "timePoint",
        "type": "type",
        "upper_bound_endpoint_behavior": "upperBoundEndpointBehavior",
        "upper_bound_time_point": "upperBoundTimePoint",
        "lower_bound_endpoint_behavior": "lowerBoundEndpointBehavior",
        "lower_bound_time_point": "lowerBoundTimePoint",
    }

    def __init__(
        self,
        include_objects_with_no_value_set=None,
        operation_type=None,
        value=None,
        operator=None,
        requires_time_zone_conversion=None,
        timestamp=None,
        upper_bound=None,
        lower_bound=None,
        default_comparison_value=None,
        comparison_property_name=None,
        number_of_days=None,
        values=None,
        month=None,
        year=None,
        day=None,
        use_fiscal_year=None,
        fiscal_year_start=None,
        time_unit_count=None,
        time_unit=None,
        endpoint_behavior=None,
        property_parser=None,
        time_point=None,
        type="TIME_RANGED",
        upper_bound_endpoint_behavior=None,
        upper_bound_time_point=None,
        lower_bound_endpoint_behavior=None,
        lower_bound_time_point=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicSurveyMonkeyValueFilterValueComparison - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._include_objects_with_no_value_set = None
        self._operation_type = None
        self._value = None
        self._operator = None
        self._requires_time_zone_conversion = None
        self._timestamp = None
        self._upper_bound = None
        self._lower_bound = None
        self._default_comparison_value = None
        self._comparison_property_name = None
        self._number_of_days = None
        self._values = None
        self._month = None
        self._year = None
        self._day = None
        self._use_fiscal_year = None
        self._fiscal_year_start = None
        self._time_unit_count = None
        self._time_unit = None
        self._endpoint_behavior = None
        self._property_parser = None
        self._time_point = None
        self._type = None
        self._upper_bound_endpoint_behavior = None
        self._upper_bound_time_point = None
        self._lower_bound_endpoint_behavior = None
        self._lower_bound_time_point = None
        self.discriminator = None

        self.include_objects_with_no_value_set = include_objects_with_no_value_set
        self.operation_type = operation_type
        self.value = value
        self.operator = operator
        self.requires_time_zone_conversion = requires_time_zone_conversion
        self.timestamp = timestamp
        self.upper_bound = upper_bound
        self.lower_bound = lower_bound
        if default_comparison_value is not None:
            self.default_comparison_value = default_comparison_value
        self.comparison_property_name = comparison_property_name
        self.number_of_days = number_of_days
        self.values = values
        self.month = month
        self.year = year
        self.day = day
        if use_fiscal_year is not None:
            self.use_fiscal_year = use_fiscal_year
        if fiscal_year_start is not None:
            self.fiscal_year_start = fiscal_year_start
        if time_unit_count is not None:
            self.time_unit_count = time_unit_count
        self.time_unit = time_unit
        if endpoint_behavior is not None:
            self.endpoint_behavior = endpoint_behavior
        if property_parser is not None:
            self.property_parser = property_parser
        self.time_point = time_point
        self.type = type
        if upper_bound_endpoint_behavior is not None:
            self.upper_bound_endpoint_behavior = upper_bound_endpoint_behavior
        self.upper_bound_time_point = upper_bound_time_point
        if lower_bound_endpoint_behavior is not None:
            self.lower_bound_endpoint_behavior = lower_bound_endpoint_behavior
        self.lower_bound_time_point = lower_bound_time_point

    @property
    def include_objects_with_no_value_set(self):
        """Gets the include_objects_with_no_value_set of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The include_objects_with_no_value_set of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: bool
        """
        return self._include_objects_with_no_value_set

    @include_objects_with_no_value_set.setter
    def include_objects_with_no_value_set(self, include_objects_with_no_value_set):
        """Sets the include_objects_with_no_value_set of this PublicSurveyMonkeyValueFilterValueComparison.


        :param include_objects_with_no_value_set: The include_objects_with_no_value_set of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type include_objects_with_no_value_set: bool
        """
        if self.local_vars_configuration.client_side_validation and include_objects_with_no_value_set is None:  # noqa: E501
            raise ValueError("Invalid value for `include_objects_with_no_value_set`, must not be `None`")  # noqa: E501

        self._include_objects_with_no_value_set = include_objects_with_no_value_set

    @property
    def operation_type(self):
        """Gets the operation_type of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The operation_type of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: str
        """
        return self._operation_type

    @operation_type.setter
    def operation_type(self, operation_type):
        """Sets the operation_type of this PublicSurveyMonkeyValueFilterValueComparison.


        :param operation_type: The operation_type of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type operation_type: str
        """
        if self.local_vars_configuration.client_side_validation and operation_type is None:  # noqa: E501
            raise ValueError("Invalid value for `operation_type`, must not be `None`")  # noqa: E501

        self._operation_type = operation_type

    @property
    def value(self):
        """Gets the value of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The value of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this PublicSurveyMonkeyValueFilterValueComparison.


        :param value: The value of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type value: str
        """
        if self.local_vars_configuration.client_side_validation and value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def operator(self):
        """Gets the operator of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The operator of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this PublicSurveyMonkeyValueFilterValueComparison.


        :param operator: The operator of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type operator: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501

        self._operator = operator

    @property
    def requires_time_zone_conversion(self):
        """Gets the requires_time_zone_conversion of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The requires_time_zone_conversion of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: bool
        """
        return self._requires_time_zone_conversion

    @requires_time_zone_conversion.setter
    def requires_time_zone_conversion(self, requires_time_zone_conversion):
        """Sets the requires_time_zone_conversion of this PublicSurveyMonkeyValueFilterValueComparison.


        :param requires_time_zone_conversion: The requires_time_zone_conversion of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type requires_time_zone_conversion: bool
        """
        if self.local_vars_configuration.client_side_validation and requires_time_zone_conversion is None:  # noqa: E501
            raise ValueError("Invalid value for `requires_time_zone_conversion`, must not be `None`")  # noqa: E501

        self._requires_time_zone_conversion = requires_time_zone_conversion

    @property
    def timestamp(self):
        """Gets the timestamp of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The timestamp of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this PublicSurveyMonkeyValueFilterValueComparison.


        :param timestamp: The timestamp of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type timestamp: int
        """
        if self.local_vars_configuration.client_side_validation and timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `timestamp`, must not be `None`")  # noqa: E501

        self._timestamp = timestamp

    @property
    def upper_bound(self):
        """Gets the upper_bound of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The upper_bound of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: int
        """
        return self._upper_bound

    @upper_bound.setter
    def upper_bound(self, upper_bound):
        """Sets the upper_bound of this PublicSurveyMonkeyValueFilterValueComparison.


        :param upper_bound: The upper_bound of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type upper_bound: int
        """
        if self.local_vars_configuration.client_side_validation and upper_bound is None:  # noqa: E501
            raise ValueError("Invalid value for `upper_bound`, must not be `None`")  # noqa: E501

        self._upper_bound = upper_bound

    @property
    def lower_bound(self):
        """Gets the lower_bound of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The lower_bound of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: int
        """
        return self._lower_bound

    @lower_bound.setter
    def lower_bound(self, lower_bound):
        """Sets the lower_bound of this PublicSurveyMonkeyValueFilterValueComparison.


        :param lower_bound: The lower_bound of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type lower_bound: int
        """
        if self.local_vars_configuration.client_side_validation and lower_bound is None:  # noqa: E501
            raise ValueError("Invalid value for `lower_bound`, must not be `None`")  # noqa: E501

        self._lower_bound = lower_bound

    @property
    def default_comparison_value(self):
        """Gets the default_comparison_value of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The default_comparison_value of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: str
        """
        return self._default_comparison_value

    @default_comparison_value.setter
    def default_comparison_value(self, default_comparison_value):
        """Sets the default_comparison_value of this PublicSurveyMonkeyValueFilterValueComparison.


        :param default_comparison_value: The default_comparison_value of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type default_comparison_value: str
        """

        self._default_comparison_value = default_comparison_value

    @property
    def comparison_property_name(self):
        """Gets the comparison_property_name of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The comparison_property_name of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: str
        """
        return self._comparison_property_name

    @comparison_property_name.setter
    def comparison_property_name(self, comparison_property_name):
        """Sets the comparison_property_name of this PublicSurveyMonkeyValueFilterValueComparison.


        :param comparison_property_name: The comparison_property_name of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type comparison_property_name: str
        """
        if self.local_vars_configuration.client_side_validation and comparison_property_name is None:  # noqa: E501
            raise ValueError("Invalid value for `comparison_property_name`, must not be `None`")  # noqa: E501

        self._comparison_property_name = comparison_property_name

    @property
    def number_of_days(self):
        """Gets the number_of_days of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The number_of_days of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: int
        """
        return self._number_of_days

    @number_of_days.setter
    def number_of_days(self, number_of_days):
        """Sets the number_of_days of this PublicSurveyMonkeyValueFilterValueComparison.


        :param number_of_days: The number_of_days of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type number_of_days: int
        """
        if self.local_vars_configuration.client_side_validation and number_of_days is None:  # noqa: E501
            raise ValueError("Invalid value for `number_of_days`, must not be `None`")  # noqa: E501

        self._number_of_days = number_of_days

    @property
    def values(self):
        """Gets the values of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The values of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: list[str]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this PublicSurveyMonkeyValueFilterValueComparison.


        :param values: The values of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type values: list[str]
        """
        if self.local_vars_configuration.client_side_validation and values is None:  # noqa: E501
            raise ValueError("Invalid value for `values`, must not be `None`")  # noqa: E501

        self._values = values

    @property
    def month(self):
        """Gets the month of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The month of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: str
        """
        return self._month

    @month.setter
    def month(self, month):
        """Sets the month of this PublicSurveyMonkeyValueFilterValueComparison.


        :param month: The month of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type month: str
        """
        if self.local_vars_configuration.client_side_validation and month is None:  # noqa: E501
            raise ValueError("Invalid value for `month`, must not be `None`")  # noqa: E501

        self._month = month

    @property
    def year(self):
        """Gets the year of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The year of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: int
        """
        return self._year

    @year.setter
    def year(self, year):
        """Sets the year of this PublicSurveyMonkeyValueFilterValueComparison.


        :param year: The year of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type year: int
        """
        if self.local_vars_configuration.client_side_validation and year is None:  # noqa: E501
            raise ValueError("Invalid value for `year`, must not be `None`")  # noqa: E501

        self._year = year

    @property
    def day(self):
        """Gets the day of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The day of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: int
        """
        return self._day

    @day.setter
    def day(self, day):
        """Sets the day of this PublicSurveyMonkeyValueFilterValueComparison.


        :param day: The day of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type day: int
        """
        if self.local_vars_configuration.client_side_validation and day is None:  # noqa: E501
            raise ValueError("Invalid value for `day`, must not be `None`")  # noqa: E501

        self._day = day

    @property
    def use_fiscal_year(self):
        """Gets the use_fiscal_year of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The use_fiscal_year of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: bool
        """
        return self._use_fiscal_year

    @use_fiscal_year.setter
    def use_fiscal_year(self, use_fiscal_year):
        """Sets the use_fiscal_year of this PublicSurveyMonkeyValueFilterValueComparison.


        :param use_fiscal_year: The use_fiscal_year of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type use_fiscal_year: bool
        """

        self._use_fiscal_year = use_fiscal_year

    @property
    def fiscal_year_start(self):
        """Gets the fiscal_year_start of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The fiscal_year_start of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: str
        """
        return self._fiscal_year_start

    @fiscal_year_start.setter
    def fiscal_year_start(self, fiscal_year_start):
        """Sets the fiscal_year_start of this PublicSurveyMonkeyValueFilterValueComparison.


        :param fiscal_year_start: The fiscal_year_start of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type fiscal_year_start: str
        """
        allowed_values = ["JANUARY", "FEBRUARY", "MARCH", "APRIL", "MAY", "JUNE", "JULY", "AUGUST", "SEPTEMBER", "OCTOBER", "NOVEMBER", "DECEMBER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and fiscal_year_start not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `fiscal_year_start` ({0}), must be one of {1}".format(fiscal_year_start, allowed_values))  # noqa: E501

        self._fiscal_year_start = fiscal_year_start

    @property
    def time_unit_count(self):
        """Gets the time_unit_count of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The time_unit_count of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: int
        """
        return self._time_unit_count

    @time_unit_count.setter
    def time_unit_count(self, time_unit_count):
        """Sets the time_unit_count of this PublicSurveyMonkeyValueFilterValueComparison.


        :param time_unit_count: The time_unit_count of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type time_unit_count: int
        """

        self._time_unit_count = time_unit_count

    @property
    def time_unit(self):
        """Gets the time_unit of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The time_unit of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: str
        """
        return self._time_unit

    @time_unit.setter
    def time_unit(self, time_unit):
        """Sets the time_unit of this PublicSurveyMonkeyValueFilterValueComparison.


        :param time_unit: The time_unit of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type time_unit: str
        """
        if self.local_vars_configuration.client_side_validation and time_unit is None:  # noqa: E501
            raise ValueError("Invalid value for `time_unit`, must not be `None`")  # noqa: E501

        self._time_unit = time_unit

    @property
    def endpoint_behavior(self):
        """Gets the endpoint_behavior of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The endpoint_behavior of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: str
        """
        return self._endpoint_behavior

    @endpoint_behavior.setter
    def endpoint_behavior(self, endpoint_behavior):
        """Sets the endpoint_behavior of this PublicSurveyMonkeyValueFilterValueComparison.


        :param endpoint_behavior: The endpoint_behavior of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type endpoint_behavior: str
        """

        self._endpoint_behavior = endpoint_behavior

    @property
    def property_parser(self):
        """Gets the property_parser of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The property_parser of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: str
        """
        return self._property_parser

    @property_parser.setter
    def property_parser(self, property_parser):
        """Sets the property_parser of this PublicSurveyMonkeyValueFilterValueComparison.


        :param property_parser: The property_parser of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type property_parser: str
        """

        self._property_parser = property_parser

    @property
    def time_point(self):
        """Gets the time_point of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The time_point of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: PublicTimePointOperationTimePoint
        """
        return self._time_point

    @time_point.setter
    def time_point(self, time_point):
        """Sets the time_point of this PublicSurveyMonkeyValueFilterValueComparison.


        :param time_point: The time_point of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type time_point: PublicTimePointOperationTimePoint
        """
        if self.local_vars_configuration.client_side_validation and time_point is None:  # noqa: E501
            raise ValueError("Invalid value for `time_point`, must not be `None`")  # noqa: E501

        self._time_point = time_point

    @property
    def type(self):
        """Gets the type of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The type of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PublicSurveyMonkeyValueFilterValueComparison.


        :param type: The type of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["TIME_RANGED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `type` ({0}), must be one of {1}".format(type, allowed_values))  # noqa: E501

        self._type = type

    @property
    def upper_bound_endpoint_behavior(self):
        """Gets the upper_bound_endpoint_behavior of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The upper_bound_endpoint_behavior of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: str
        """
        return self._upper_bound_endpoint_behavior

    @upper_bound_endpoint_behavior.setter
    def upper_bound_endpoint_behavior(self, upper_bound_endpoint_behavior):
        """Sets the upper_bound_endpoint_behavior of this PublicSurveyMonkeyValueFilterValueComparison.


        :param upper_bound_endpoint_behavior: The upper_bound_endpoint_behavior of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type upper_bound_endpoint_behavior: str
        """

        self._upper_bound_endpoint_behavior = upper_bound_endpoint_behavior

    @property
    def upper_bound_time_point(self):
        """Gets the upper_bound_time_point of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The upper_bound_time_point of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: PublicTimePointOperationTimePoint
        """
        return self._upper_bound_time_point

    @upper_bound_time_point.setter
    def upper_bound_time_point(self, upper_bound_time_point):
        """Sets the upper_bound_time_point of this PublicSurveyMonkeyValueFilterValueComparison.


        :param upper_bound_time_point: The upper_bound_time_point of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type upper_bound_time_point: PublicTimePointOperationTimePoint
        """
        if self.local_vars_configuration.client_side_validation and upper_bound_time_point is None:  # noqa: E501
            raise ValueError("Invalid value for `upper_bound_time_point`, must not be `None`")  # noqa: E501

        self._upper_bound_time_point = upper_bound_time_point

    @property
    def lower_bound_endpoint_behavior(self):
        """Gets the lower_bound_endpoint_behavior of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The lower_bound_endpoint_behavior of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: str
        """
        return self._lower_bound_endpoint_behavior

    @lower_bound_endpoint_behavior.setter
    def lower_bound_endpoint_behavior(self, lower_bound_endpoint_behavior):
        """Sets the lower_bound_endpoint_behavior of this PublicSurveyMonkeyValueFilterValueComparison.


        :param lower_bound_endpoint_behavior: The lower_bound_endpoint_behavior of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type lower_bound_endpoint_behavior: str
        """

        self._lower_bound_endpoint_behavior = lower_bound_endpoint_behavior

    @property
    def lower_bound_time_point(self):
        """Gets the lower_bound_time_point of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501


        :return: The lower_bound_time_point of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :rtype: PublicTimePointOperationTimePoint
        """
        return self._lower_bound_time_point

    @lower_bound_time_point.setter
    def lower_bound_time_point(self, lower_bound_time_point):
        """Sets the lower_bound_time_point of this PublicSurveyMonkeyValueFilterValueComparison.


        :param lower_bound_time_point: The lower_bound_time_point of this PublicSurveyMonkeyValueFilterValueComparison.  # noqa: E501
        :type lower_bound_time_point: PublicTimePointOperationTimePoint
        """
        if self.local_vars_configuration.client_side_validation and lower_bound_time_point is None:  # noqa: E501
            raise ValueError("Invalid value for `lower_bound_time_point`, must not be `None`")  # noqa: E501

        self._lower_bound_time_point = lower_bound_time_point

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicSurveyMonkeyValueFilterValueComparison):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicSurveyMonkeyValueFilterValueComparison):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Transactional Single Send

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.marketing.transactional.api.public_smtp_tokens_api import PublicSMTPTokensApi
from hubspot.marketing.transactional.api.single_send_api import SingleSendApi

# import ApiClient
from hubspot.marketing.transactional.api_client import ApiClient
from hubspot.marketing.transactional.configuration import Configuration
from hubspot.marketing.transactional.exceptions import OpenApiException
from hubspot.marketing.transactional.exceptions import ApiTypeError
from hubspot.marketing.transactional.exceptions import ApiValueError
from hubspot.marketing.transactional.exceptions import ApiKeyError
from hubspot.marketing.transactional.exceptions import ApiAttributeError
from hubspot.marketing.transactional.exceptions import ApiException

# import models into sdk package
from hubspot.marketing.transactional.models.collection_response_smtp_api_token_view_forward_paging import CollectionResponseSmtpApiTokenViewForwardPaging
from hubspot.marketing.transactional.models.email_send_status_view import EmailSendStatusView
from hubspot.marketing.transactional.models.error import Error
from hubspot.marketing.transactional.models.error_detail import ErrorDetail
from hubspot.marketing.transactional.models.event_id_view import EventIdView
from hubspot.marketing.transactional.models.forward_paging import ForwardPaging
from hubspot.marketing.transactional.models.next_page import NextPage
from hubspot.marketing.transactional.models.public_single_send_email import PublicSingleSendEmail
from hubspot.marketing.transactional.models.public_single_send_request_egg import PublicSingleSendRequestEgg
from hubspot.marketing.transactional.models.smtp_api_token_request_egg import SmtpApiTokenRequestEgg
from hubspot.marketing.transactional.models.smtp_api_token_view import SmtpApiTokenView



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.crm.lists.api.folders_api import FoldersApi
from hubspot.crm.lists.api.lists_api import ListsApi
from hubspot.crm.lists.api.mapping_api import MappingApi
from hubspot.crm.lists.api.memberships_api import MembershipsApi



# coding: utf-8

# flake8: noqa
"""
    Automation Actions V4

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v4
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.automation.actions.models.batch_input_callback_completion_batch_request import BatchInputCallbackCompletionBatchRequest
from hubspot.automation.actions.models.callback_completion_batch_request import CallbackCompletionBatchRequest
from hubspot.automation.actions.models.callback_completion_request import CallbackCompletionRequest
from hubspot.automation.actions.models.collection_response_public_action_definition_forward_paging import CollectionResponsePublicActionDefinitionForwardPaging
from hubspot.automation.actions.models.collection_response_public_action_function_identifier_no_paging import CollectionResponsePublicActionFunctionIdentifierNoPaging
from hubspot.automation.actions.models.collection_response_public_action_revision_forward_paging import CollectionResponsePublicActionRevisionForwardPaging
from hubspot.automation.actions.models.error import Error
from hubspot.automation.actions.models.error_detail import ErrorDetail
from hubspot.automation.actions.models.field_type_definition import FieldTypeDefinition
from hubspot.automation.actions.models.forward_paging import ForwardPaging
from hubspot.automation.actions.models.input_field_definition import InputFieldDefinition
from hubspot.automation.actions.models.next_page import NextPage
from hubspot.automation.actions.models.option import Option
from hubspot.automation.actions.models.output_field_definition import OutputFieldDefinition
from hubspot.automation.actions.models.public_action_definition import PublicActionDefinition
from hubspot.automation.actions.models.public_action_definition_egg import PublicActionDefinitionEgg
from hubspot.automation.actions.models.public_action_definition_input_field_dependencies_inner import PublicActionDefinitionInputFieldDependenciesInner
from hubspot.automation.actions.models.public_action_definition_patch import PublicActionDefinitionPatch
from hubspot.automation.actions.models.public_action_function import PublicActionFunction
from hubspot.automation.actions.models.public_action_function_identifier import PublicActionFunctionIdentifier
from hubspot.automation.actions.models.public_action_labels import PublicActionLabels
from hubspot.automation.actions.models.public_action_revision import PublicActionRevision
from hubspot.automation.actions.models.public_conditional_single_field_dependency import PublicConditionalSingleFieldDependency
from hubspot.automation.actions.models.public_execution_translation_rule import PublicExecutionTranslationRule
from hubspot.automation.actions.models.public_object_request_options import PublicObjectRequestOptions
from hubspot.automation.actions.models.public_single_field_dependency import PublicSingleFieldDependency



import hubspot.crm.extensions.videoconferencing as api_client
from ....discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def settings_api(self) -> api_client.SettingsApi:
        return self._configure_api_client(api_client, "SettingsApi")



# coding: utf-8

"""
    Webhooks Webhooks

    Provides a way for apps to subscribe to certain change events in HubSpot. Once configured, apps will receive event payloads containing details about the changes at a specified target URL. There can only be one target URL for receiving event notifications per app.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.webhooks.configuration import Configuration


class SettingsResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"created_at": "datetime", "throttling": "ThrottlingSettings", "target_url": "str", "updated_at": "datetime"}

    attribute_map = {"created_at": "createdAt", "throttling": "throttling", "target_url": "targetUrl", "updated_at": "updatedAt"}

    def __init__(self, created_at=None, throttling=None, target_url=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """SettingsResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_at = None
        self._throttling = None
        self._target_url = None
        self._updated_at = None
        self.discriminator = None

        self.created_at = created_at
        self.throttling = throttling
        self.target_url = target_url
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def created_at(self):
        """Gets the created_at of this SettingsResponse.  # noqa: E501

        When this subscription was created. Formatted as milliseconds from the [Unix epoch](#).  # noqa: E501

        :return: The created_at of this SettingsResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this SettingsResponse.

        When this subscription was created. Formatted as milliseconds from the [Unix epoch](#).  # noqa: E501

        :param created_at: The created_at of this SettingsResponse.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def throttling(self):
        """Gets the throttling of this SettingsResponse.  # noqa: E501


        :return: The throttling of this SettingsResponse.  # noqa: E501
        :rtype: ThrottlingSettings
        """
        return self._throttling

    @throttling.setter
    def throttling(self, throttling):
        """Sets the throttling of this SettingsResponse.


        :param throttling: The throttling of this SettingsResponse.  # noqa: E501
        :type throttling: ThrottlingSettings
        """
        if self.local_vars_configuration.client_side_validation and throttling is None:  # noqa: E501
            raise ValueError("Invalid value for `throttling`, must not be `None`")  # noqa: E501

        self._throttling = throttling

    @property
    def target_url(self):
        """Gets the target_url of this SettingsResponse.  # noqa: E501

        A publicly available URL for HubSpot to call where event payloads will be delivered. See [link-so-some-doc](#) for details about the format of these event payloads.  # noqa: E501

        :return: The target_url of this SettingsResponse.  # noqa: E501
        :rtype: str
        """
        return self._target_url

    @target_url.setter
    def target_url(self, target_url):
        """Sets the target_url of this SettingsResponse.

        A publicly available URL for HubSpot to call where event payloads will be delivered. See [link-so-some-doc](#) for details about the format of these event payloads.  # noqa: E501

        :param target_url: The target_url of this SettingsResponse.  # noqa: E501
        :type target_url: str
        """
        if self.local_vars_configuration.client_side_validation and target_url is None:  # noqa: E501
            raise ValueError("Invalid value for `target_url`, must not be `None`")  # noqa: E501

        self._target_url = target_url

    @property
    def updated_at(self):
        """Gets the updated_at of this SettingsResponse.  # noqa: E501

        When this subscription was last updated. Formatted as milliseconds from the [Unix epoch](#).  # noqa: E501

        :return: The updated_at of this SettingsResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this SettingsResponse.

        When this subscription was last updated. Formatted as milliseconds from the [Unix epoch](#).  # noqa: E501

        :param updated_at: The updated_at of this SettingsResponse.  # noqa: E501
        :type updated_at: datetime
        """

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SettingsResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SettingsResponse):
            return True

        return self.to_dict() != other.to_dict()
